@@ -274,11 +274,9 @@
 #' x <- lapply(
 #'   X = seq_len(n),
 #'   FUN = function(i) {
-#'     return(
-#'       matrix(
-#'         data = rnorm(n = j * time),
-#'         nrow = j
-#'       )
+#'     matrix(
+#'       data = rnorm(n = j * time),
+#'       nrow = j
 #'     )
 #'   }
 #' )
@@ -429,7 +427,5 @@ SimSSMLinGrowth <- function(n, time,
     "simstatespace",
     class(out)
   )
-  return(
-    out
-  )
+  out
 }
